Python: module glottolog

glottolog | index /home/misha/Проекты/lingtypology/lingtypology/lingtypology/glottolog.py

`Using data from Glottolog DB`

Modules
`` |  |
os | pandas |  |

Functions
`` |  | get_affiliations(languages) `get_affiliations(('Russian', 'English')) >>> ['Indo-European, Balto-Slavic, Slavic, East Slavic', 'Indo-European, ...']` get_by_glot_id(glot_id) `get_by_glot_id('russ1263') >>> Russian` get_by_iso(iso) `get_by_iso('rus') >>> Russian` get_coordinates(language) `get_coordinates('Russian') >>> (59.0, 50.0)` get_glot_id(language) `get_glot_id('Russian') >>> russ1263` get_glot_id_by_iso(iso) `get_glot_id_by_iso('rus') >>> russ1263` get_glottolog_table(directory) `get name of the CSV and version This function returns name and version of the proper CSV-file containing Glottolog data. glottolog utility from pyglottolog package creates the CSV table and names it: glottolog-languoids-pyglottolog-[version-version-version].csv` get_iso(language) `get_iso('Russian') >>> rus` get_iso_by_glot_id(glot_id) `get_iso_by_glot_id('russ1263') >>> rus` get_macro_area(language) `get_macro_area('Russian') >>> Eurasia`

Data
`` |  | glottolog = ID Name M...ialect NaN [24344 rows x 14 columns] home = PosixPath('/home/misha') module_directory = '/home/misha/Проекты/lingtypology/lingtypology/lingtypology' path = '/home/misha/Проекты/lingtypology/lingtypology/li...pology/glottolog-languoids-v3.4-7-gfa9d1ec7c5.csv' version = 'v3.4-7-gfa9d1ec7c5' warnings = []